/*
 * Copyright (C) 2005 Alex Murray <pragmatine@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef I8K_SENSORS_INTERFACE_H
#define I8K_SENSORS_INTERFACE_H

#include "sensors-applet.h"

/* function definitions */
void i8k_sensors_interface_init(SensorsApplet *sensors_applet);
gdouble i8k_sensors_interface_get_sensor_value(const gchar *path, 
					      const gchar *id, 
					      SensorType type,
					      GError **error);

#endif /* I8K_SENSORS_INTERFACE_H */
